==> mobile_garland-5.x-1.0.tar.gz: mobile_garland/template.php <==
<?php
// $Id: template.php,v 1.1 2009/05/10 20:33:39 teemule Exp $

/**
 * Mobile_Garland is a Garland inspired mobile optimized Drupal theme.
 * The theme should be used with the Hello Mobile -module.
 * Nitro FX Oy, Finland 2009
 * Mikko Hyytiainen, Teemu Lehtinen
 */

/**
 * Names the existing regions in this theme.
 * @return a map of region names
 */
function mobile_garland_regions() {
	return array(
		'left' => t('left sidebar'),
		'right' => t('right sidebar'),
		'content' => t('content'),
		'header' => t('header'),
		'footer' => t('footer'),
		'mobile_footer' => t('mobile footer')
	);
}

/**
 * Preprocesses template variables.
 * @param hook a hook at hand
 * @param vars variables for the template
 * @return preprocessed variables for the template
 */
function _phptemplate_variables($hook, $vars = array()) {
	if ($hook == 'page' && module_exists('hellomobile')) {
		$vars['styles'] = _hellomobile_filter_css();
		$vars['scripts'] = _hellomobile_filter_js();
		$vars['bodyclasses'] = 'mobile' . _hellomobile_add_class();
	}
	return $vars;
}

/**
 * Themes the top links.
 * @param links links data
 * @param attributes attributes to add for the element
 * @return top links markup
 */
function mobile_garland_toplinks($links, $attributes = array('class' => 'links')) {
	$num_links = count($links);
	if ($num_links == 0) {
		return '';
	}
	$output = '<div'. drupal_attributes($attributes) .'>';
	$i = 1;
	foreach ($links as $key => $link) {

		// Add active or passive class to links.
		$active = (strpos($key, '-active') ? ' active' : ' passive');
		if (isset($link['attributes']) && isset($link['attributes']['class'])) {
			$link['attributes']['class'] .= ' ' . $key;
		}
		else {
			$link['attributes']['class'] = $key;
		}

		// Add first and last classes to links.
		$extra_class = '';
		if ($i == 1) {
			$extra_class .= 'first ';
		}
		if ($i == $num_links) {
			$extra_class .= 'last ';
		}
		$output .= '<span '. drupal_attributes(array('class' => $extra_class . $key . $active)) .'>';

		// Create a link or plain title.
		$html = isset($link['html']) && $link['html'];
		$link['query'] = isset($link['query']) ? $link['query'] : NULL;
		$link['fragment'] = isset($link['fragment']) ? $link['fragment'] : NULL;
		if (isset($link['href'])) {
			$output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment'], FALSE, $html);
		} else if ($link['title']) {
			if (!$html) {
				$link['title'] = check_plain($link['title']);
			}
			$output .= '<span'. drupal_attributes($link['attributes']) .'>'. $link['title'] .'</span>';
		}
		$output .= "</span>\n";
		$i++;
	}
	$output .= '</div>';
	return $output;
}

/**
 * Wraps comments to a stylable element.
 * @param content the comment markup
 * @param type a node type
 * @return full comment markup
 */
function phptemplate_comment_wrapper($content, $type = null) {
	if (!$content || $type == 'forum') {
		return '<div id="comments">' . $content . '</div>';
	}
	return '<div id="comments"><h2 class="comments">' . t('Comments') . '</h2>' . $content . '</div>';
}

==> mobile_garland-5.x-1.2.tar.gz: mobile_garland/template.php <==
<?php
// $Id: template.php,v 1.2 2009/05/19 13:50:44 teemule Exp $

/**
 * Mobile_Garland is a Garland inspired mobile optimized Drupal theme.
 * The theme should be used with the Mobile Plugin -module.
 * Nitro FX Oy, Finland 2009
 * Mikko Hyytiainen, Teemu Lehtinen
 */

/**
 * Names the existing regions in this theme.
 * @return a map of region names
 */
function mobile_garland_regions() {
	return array(
		'left' => t('left sidebar'),
		'right' => t('right sidebar'),
		'content' => t('content'),
		'header' => t('header'),
		'footer' => t('footer'),
		'mobile_footer' => t('mobile footer')
	);
}

/**
 * Preprocesses template variables.
 * @param hook a hook at hand
 * @param vars variables for the template
 * @return preprocessed variables for the template
 */
function _phptemplate_variables($hook, $vars = array()) {
	if ($hook == 'page' && module_exists('mobileplugin')) {
		$vars['styles'] = _mobileplugin_filter_css();
		$vars['scripts'] = _mobileplugin_filter_js();
		$vars['bodyclasses'] = 'mobile' . _mobileplugin_add_class();
	}
	return $vars;
}

/**
 * Themes the top links.
 * @param links links data
 * @param attributes attributes to add for the element
 * @return top links markup
 */
function mobile_garland_toplinks($links, $attributes = array('class' => 'links')) {
	$num_links = count($links);
	if ($num_links == 0) {
		return '';
	}
	$output = '<div'. drupal_attributes($attributes) .'>';
	$i = 1;
	foreach ($links as $key => $link) {

		// Add active or passive class to links.
		$active = (strpos($key, '-active') ? ' active' : ' passive');
		if (isset($link['attributes']) && isset($link['attributes']['class'])) {
			$link['attributes']['class'] .= ' ' . $key;
		}
		else {
			$link['attributes']['class'] = $key;
		}

		// Add first and last classes to links.
		$extra_class = '';
		if ($i == 1) {
			$extra_class .= 'first ';
		}
		if ($i == $num_links) {
			$extra_class .= 'last ';
		}
		$output .= '<span '. drupal_attributes(array('class' => $extra_class . $key . $active)) .'>';

		// Create a link or plain title.
		$html = isset($link['html']) && $link['html'];
		$link['query'] = isset($link['query']) ? $link['query'] : NULL;
		$link['fragment'] = isset($link['fragment']) ? $link['fragment'] : NULL;
		if (isset($link['href'])) {
			$output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment'], FALSE, $html);
		} else if ($link['title']) {
			if (!$html) {
				$link['title'] = check_plain($link['title']);
			}
			$output .= '<span'. drupal_attributes($link['attributes']) .'>'. $link['title'] .'</span>';
		}
		$output .= "</span>\n";
		$i++;
	}
	$output .= '</div>';
	return $output;
}

/**
 * Wraps comments to a stylable element.
 * @param content the comment markup
 * @param type a node type
 * @return full comment markup
 */
function phptemplate_comment_wrapper($content, $type = null) {
	if (!$content || $type == 'forum') {
		return '<div id="comments">' . $content . '</div>';
	}
	return '<div id="comments"><h2 class="comments">' . t('Comments') . '</h2>' . $content . '</div>';
}
